@@ -224,7 +224,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libisofs_req_major  1
 #define isoburn_libisofs_req_minor  0
-#define isoburn_libisofs_req_micro  4 
+#define isoburn_libisofs_req_micro  5 
 
 /** The minimum version of libburn to be used with this version of libisoburn
     at compile time.
@@ -232,7 +232,7 @@ void isoburn_version(int *major, int *minor, int *micro);
 */
 #define isoburn_libburn_req_major  1
 #define isoburn_libburn_req_minor  0
-#define isoburn_libburn_req_micro  4
+#define isoburn_libburn_req_micro  5
 
 /** The minimum compile time requirements of libisoburn towards libjte are
     the same as of a suitable libisofs towards libjte.
@@ -287,7 +287,7 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
 */
 #define isoburn_header_version_major  1
 #define isoburn_header_version_minor  0
-#define isoburn_header_version_micro  4
+#define isoburn_header_version_micro  5
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -403,8 +403,9 @@ int isoburn_drive_scan_and_grab(struct burn_drive_info *drive_infos[],
     @param flag   bit0= attempt to load the disc tray.
                         Else: failure if not loaded.
                   bit1= regard overwriteable media as blank
-                  bit2= if the drive is a regular disk file: truncate it to
-                        the write start address
+                  bit2= if the drive is a regular disk file:
+                        truncate it to the write start address when writing
+                        begins
                   bit3= if the drive reports a read-only profile try to read
                         table of content by scanning for ISO image headers.
                         (depending on media type and drive this might
@@ -1115,6 +1116,10 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
                  only 8 characters.
                  (mkisofs and its clones obviously do this violation.)
                  @since 1.0.0
+          bit15= joliet_long_names
+                 Allow for Joliet leaf names up to 103 characters rather than
+                 up to 64.
+                 @since 1.0.6
     @return 1 success, <=0 failure
 */
 #define isoburn_igopt_omit_version_numbers       1
@@ -1132,6 +1137,7 @@ int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
 #define isoburn_igopt_only_iso_versions       4096
 #define isoburn_igopt_no_j_force_dots         8192
 #define isoburn_igopt_allow_dir_id_ext       16384
+#define isoburn_igopt_joliet_long_names      32768
 int isoburn_igopt_set_relaxed(struct isoburn_imgen_opts *o, int relax);
 int isoburn_igopt_get_relaxed(struct isoburn_imgen_opts *o, int *relax);
 
@@ -1833,6 +1839,21 @@ int isoburn_cancel_prepared_write(struct burn_drive *input_drive,
                                   struct burn_drive *output_drive, int flag);
 
 
+/**
+    Override the truncation setting that was made with flag bit2 during the
+    call of isoburn_drive_aquire. This applies only to stdio pseudo drives.
+    @since 0.1.6
+    @param drive The drive which was aquired and shall be used for writing.
+    @param flag Bitfield controlling the setting:
+                bit0= truncate (else do not truncate)
+                bit1= do not warn if call is inappropriate to drive
+                bit2= only set if truncation is currently enabled
+                      do not warn if call is inappropriate to drive
+    @return     1 success, 0 inappropriate drive, <0 severe error
+*/
+int isoburn_set_truncate(struct burn_drive *drive, int flag);
+
+
 /** Start writing of the new session.
     This call is asynchrounous. I.e. it returns quite soon and the progress has
     to be watched by a loop with call burn_drive_get_status() until
