@@ -767,7 +767,10 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
    {ret= 0; goto ex;}
  isoburn_igopt_set_sort_files(sopts, 1);
  isoburn_igopt_set_over_mode(sopts, 0, 0, (mode_t) 0, (mode_t) 0);
- isoburn_igopt_set_over_ugid(sopts, 0, 0, (uid_t) 0, (gid_t) 0);
+ isoburn_igopt_set_over_ugid(sopts, 2 * !!xorriso->do_global_uid,
+                             2 * !!xorriso->do_global_gid,
+                             (uid_t) xorriso->global_uid,
+                             (gid_t) xorriso->global_gid);
  isoburn_igopt_set_out_charset(sopts, out_cs);
  isoburn_igopt_set_fifo_size(sopts, xorriso->fs * 2048);
  Ftimetxt(time(NULL), xorriso->scdbackup_tag_time, 8);
@@ -830,7 +833,7 @@ int Xorriso_write_session(struct XorrisO *xorriso, int flag)
 fprintf(stderr, "XORRISO_DEBUG: isoburn_igopt_set_tail_blocks(%d)\n",
         (int) padding);
 */
-   isoburn_igopt_set_tail_blocks(sopts, padding / 2048);
+   isoburn_igopt_set_tail_blocks(sopts, padding);
  }
 
  /* Make final abort check before starting expensive activities */
@@ -925,6 +928,11 @@ fprintf(stderr, "XORRISO_DEBUG: isoburn_igopt_set_tail_blocks(%d)\n",
  /* Important: do not return until burn_is_aborting() was checked */
  Xorriso_set_signal_handling(xorriso, 1);
 
+ /* De-activate eventual target file truncation in dummy mode */
+ ret= isoburn_set_truncate(drive, (!xorriso->do_dummy) | 2 | 4);
+ if(ret < 0)
+   goto cancel_iso;
+
  xorriso->run_state= 1; /* Indicate that burning has started */
  isoburn_disc_write(burn_options, disc);
  burn_write_opts_free(burn_options);
@@ -1757,20 +1765,29 @@ int Xorriso_burn_track(struct XorrisO *xorriso, off_t write_start_address,
  if(isoburn_needs_emulation(drive)) {
    if(flag&1) {
      ret= isoburn_disc_track_lba_nwa(drive, burn_options, 0, &dummy, &nwa);
+     Xorriso_process_msg_queues(xorriso,0);
      if(ret<=0) {
-       Xorriso_process_msg_queues(xorriso,0);
        sprintf(xorriso->info_text,
      "Cannot obtain next writeable address of emulated multi-session media\n");
        Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
        ret= 0; goto ex;
      }
-     if(nwa==32)
+     if(nwa == 32 && disc_state != BURN_DISC_APPENDABLE)
        nwa= 0; /* No automatic toc emulation. Formatter might not be aware. */
-     burn_write_opts_set_start_byte(burn_options,((off_t) nwa) * (off_t) 2048);
    } else {
      nwa= 0;
-     burn_write_opts_set_start_byte(burn_options, (off_t) 0);
+     if (disc_state == BURN_DISC_APPENDABLE) {
+       ret= isoburn_disc_track_lba_nwa(drive, burn_options, 0, &dummy, &nwa);
+       Xorriso_process_msg_queues(xorriso,0);
+       if(ret<=0) {
+         sprintf(xorriso->info_text,
+        "Cannot obtain next writeable address of emulated appendable media\n");
+         Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
+         ret= 0; goto ex;
+       }
+     }
    }
+   burn_write_opts_set_start_byte(burn_options,((off_t) nwa) * (off_t) 2048);
  }
 
  if(write_start_address>=0) {
@@ -1947,6 +1964,12 @@ int Xorriso_relax_compliance(struct XorrisO *xorriso, char *mode,
    } else if(l == 21 && strncmp(cpt, "joliet_long_paths_off", l) == 0) {
      xorriso->relax_compliance&= ~isoburn_igopt_joliet_longer_paths;
 
+   } else if((l == 17 && strncmp(cpt, "joliet_long_names", l) == 0) ||
+             (l == 20 && strncmp(cpt, "joliet_long_names_on", l) == 0)) {
+     xorriso->relax_compliance|= isoburn_igopt_joliet_long_names;
+   } else if(l == 21 && strncmp(cpt, "joliet_long_names_off", l) == 0) {
+     xorriso->relax_compliance&= ~isoburn_igopt_joliet_long_names;
+
    } else if((l == 10 && strncmp(cpt, "always_gmt", l) == 0) ||
              (l == 13 && strncmp(cpt, "always_gmt_on", l) == 0)) {
      xorriso->relax_compliance|= isoburn_igopt_always_gmt;
@@ -2058,8 +2081,7 @@ int Xorriso_get_relax_text(struct XorrisO *xorriso, char mode[1024],
    return(1);
  }
  strcpy(mode, "clear");
- if(xorriso->iso_level != 3)
-   sprintf(mode + strlen(mode), ":iso_9660_level=%d",  xorriso->iso_level);
+ sprintf(mode + strlen(mode), ":iso_9660_level=%d",  xorriso->iso_level);
  if(r & isoburn_igopt_allow_dir_id_ext)
    strcat(mode, ":allow_dir_id_ext");
  if(r & isoburn_igopt_omit_version_numbers)
@@ -2082,6 +2104,8 @@ int Xorriso_get_relax_text(struct XorrisO *xorriso, char mode[1024],
    strcat(mode, ":full_ascii");
  if(r & isoburn_igopt_joliet_longer_paths)
    strcat(mode, ":joliet_long_paths");
+ if(r & isoburn_igopt_joliet_long_names)
+   strcat(mode, ":joliet_long_names");
  if(r & isoburn_igopt_always_gmt)
    strcat(mode, ":always_gmt");
  if(r & isoburn_igopt_dir_rec_mtime)
@@ -2232,8 +2256,11 @@ int Xorriso_update_iso_lba0(struct XorrisO *xorriso, int iso_lba, int isosize,
  }
  if(iso_lba < 32)
    return(2);
+
  if(!(flag & 2)) {
    /* head_buffer was not filled yet. Read it from output media. */
+   if(burn_drive_get_drive_role(drive) == 5) /* write-only */
+     return(2);
    if(job != NULL && job->data_to_fd >= 0) {
      if((flag & 8) && job->sector_map != NULL) {
        ret= Sectorbitmap_bytes_are_set(job->sector_map,
