@@ -61,7 +61,7 @@ struct XorrisO;
 */
 #define Xorriso_header_version_majoR  1
 #define Xorriso_header_version_minoR  0
-#define Xorriso_header_version_micrO  4
+#define Xorriso_header_version_micrO  5
 
 
 /** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
@@ -802,6 +802,11 @@ int Xorriso_option_dummy(struct XorrisO *xorriso, char *mode, int flag);
 /* Option -dvd_obs "default"|"32k"|"64k" */
 int Xorriso_option_dvd_obs(struct XorrisO *xorriso, char *obs, int flag);
 
+/* Option -early_stdio_test */
+/* @since 1.0.6 */
+int Xorriso_option_early_stdio_test(struct XorrisO *xorriso, char *mode,
+                                    int flag);
+
 /* Option -eject */
 /* @param flag bit0=do not report toc of eventually remaining drives
 */
@@ -1043,7 +1048,12 @@ int Xorriso_option_pkt_output(struct XorrisO *xorriso, char *mode, int flag);
 /* @since 0.6.2 */
 int Xorriso_option_preparer_id(struct XorrisO *xorriso, char *name, int flag);
 
-/* Option -print */
+/* Options -print, -print_info , -print_mark */
+/* @param flag bit0-1= output channel:
+                       0= result channel
+                       1= info channel @since 1.0.6
+                       2= mark channel @since 1.0.6
+*/
 int Xorriso_option_print(struct XorrisO *xorriso, char *text, int flag);
 
 /* Option -print_size
